@@ -320,6 +320,14 @@ class CorpMembershipAdmin(admin.ModelAdmin):
         return HttpResponseRedirect(reverse('corpmembership.view',
                                             args=[object_id]))
 
+    def log_deletion(self, request, object, object_repr):
+        description = 'Corporate membership - %s (id=%d, corp_profile_id=%d) - deleted' % (
+                                            object.corp_profile.name,
+                                            object.id,
+                                            object.corp_profile.id)
+        EventLog.objects.log(instance=object, description=description)
+        super(CorpMembershipAdmin, self).log_deletion(request, object, object_repr)
+
 
 class NoticeAdmin(admin.ModelAdmin):
     def notice_log(self):
