@@ -6,8 +6,8 @@ import mimetypes
 from django.contrib.auth.decorators import login_required
 from django.shortcuts import get_object_or_404, redirect
 from django.template import RequestContext
-from django.http import (HttpResponseRedirect, HttpResponse, Http404,
-    HttpResponseServerError)
+from django.http import (
+    HttpResponseRedirect, HttpResponse, Http404, HttpResponseServerError)
 from django.utils import simplejson
 from django.core.urlresolvers import reverse
 from django.middleware.csrf import get_token as csrf_get_token
@@ -23,8 +23,8 @@ from tendenci.core.base.http import Http403
 from tendenci.core.site_settings.utils import get_setting
 from tendenci.core.perms.decorators import admin_required, is_enabled
 from tendenci.core.perms.object_perms import ObjectPermission
-from tendenci.core.perms.utils import (update_perms_and_save, has_perm, has_view_perm,
-    get_query_filters)
+from tendenci.core.perms.utils import (
+    update_perms_and_save, has_perm, has_view_perm, get_query_filters)
 from tendenci.core.categories.forms import CategoryForm
 from tendenci.core.categories.models import Category
 from tendenci.core.event_logs.models import EventLog
@@ -37,15 +37,23 @@ from tendenci.core.files.forms import FileForm, MostViewedForm, FileSearchForm,
 
 @is_enabled('files')
 def details(request, id, size=None, crop=False, quality=90, download=False, constrain=False, template_name="files/details.html"):
-    cache_key = generate_image_cache_key(file=id, size=size, pre_key=FILE_IMAGE_PRE_KEY, crop=crop, unique_key=id, quality=quality, constrain=constrain)
+    """
+    Return an image response after paramters have been applied.
+    """
+    cache_key = generate_image_cache_key(
+        file=id,
+        size=size,
+        pre_key=FILE_IMAGE_PRE_KEY,
+        crop=crop,
+        unique_key=id,
+        quality=quality,
+        constrain=constrain)
+
     cached_image = cache.get(cache_key)
     if cached_image:
         return redirect(cached_image)
 
-    try:
-        file = File.objects.get(pk=id)
-    except:
-        raise Http404
+    file = get_object_or_404(File, pk=id)
 
     # basic permissions
     if not has_view_perm(request.user, 'files.view_file', file):
@@ -67,9 +75,8 @@ def details(request, id, size=None, crop=False, quality=90, download=False, cons
     except IOError:  # no such file or directory
         raise Http404
 
-    # log downloads and views
-    if download:
-        attachment = 'attachment;'
+    if download:  # log download
+        attachment = u'attachment;'
         EventLog.objects.log(**{
             'event_id': 185000,
             'event_data': '%s %s (%d) dowloaded by %s' % (file.type(), file._meta.object_name, file.pk, request.user),
@@ -78,10 +85,9 @@ def details(request, id, size=None, crop=False, quality=90, download=False, cons
             'request': request,
             'instance': file,
         })
-    else:
-        attachment = ''
+    else:  # log view
+        attachment = u''
         if file.type() != 'image':
-            # log file view
             EventLog.objects.log(**{
                 'event_id': 186000,
                 'event_data': '%s %s (%d) viewed by %s' % (file.type(), file._meta.object_name, file.pk, request.user),
@@ -94,6 +100,9 @@ def details(request, id, size=None, crop=False, quality=90, download=False, cons
     # if image size specified
     if file.type() == 'image' and size:  # if size specified
 
+        if file.ext() in ('.tif', '.tiff'):
+            raise Http404  # tifs cannot (currently) be viewed via browsers
+
         size = [int(s) if s.isdigit() else 0 for s in size.split('x')]
         size = aspect_ratio(file.image_dimensions(), size, constrain)
 
@@ -104,9 +113,14 @@ def details(request, id, size=None, crop=False, quality=90, download=False, cons
 
         # gets resized image from cache or rebuilds
         image = get_image(file.file, size, FILE_IMAGE_PRE_KEY, cache=True, crop=crop, quality=quality, unique_key=None)
-        response = HttpResponse(mimetype='image/jpeg')
+        response = HttpResponse(mimetype=file.mime_type())
         response['Content-Disposition'] = '%s filename=%s' % (attachment, file.get_name())
-        image.save(response, "JPEG", quality=quality)
+
+        params = {'quality': quality}
+        if image.format == 'GIF':
+            params['transparency'] = 0
+
+        image.save(response, image.format, **params)
 
         if file.is_public_file():
             file_name = "%s%s" % (file.get_name(), ".jpg")
@@ -194,12 +208,11 @@ def search(request, template_name="files/search.html"):
 
     EventLog.objects.log()
 
-    return render_to_response(template_name,
-            {
-                'files': files,
-                'form': form,
-            },
-        context_instance=RequestContext(request))
+    return render_to_response(
+        template_name, {
+            'files': files,
+            'form': form,
+        }, context_instance=RequestContext(request))
 
 
 def search_redirect(request):
@@ -211,11 +224,13 @@ def print_view(request, id, template_name="files/print-view.html"):
     file = get_object_or_404(File, pk=id)
 
     # check permission
-    if not has_view_perm(request.user,'files.view_file',file):
+    if not has_view_perm(request.user, 'files.view_file', file):
         raise Http403
 
-    return render_to_response(template_name, {'file': file}, 
-        context_instance=RequestContext(request))
+    return render_to_response(
+        template_name, {
+            'file': file
+        }, context_instance=RequestContext(request))
 
 
 @is_enabled('files')
@@ -224,56 +239,56 @@ def edit(request, id, form_class=FileForm, category_form_class=CategoryForm, tem
     file = get_object_or_404(File, pk=id)
 
     # check permission
-    if not has_perm(request.user,'files.change_file',file):  
+    if not has_perm(request.user, 'files.change_file', file):
         raise Http403
 
-    content_type = get_object_or_404(ContentType, app_label='files',model='file')
-    
+    content_type = get_object_or_404(ContentType, app_label='files', model='file')
+
     #setup categories
-    category = Category.objects.get_for_object(file,'category')
-    sub_category = Category.objects.get_for_object(file,'sub_category')
-        
+    category = Category.objects.get_for_object(file, 'category')
+    sub_category = Category.objects.get_for_object(file, 'sub_category')
+
     initial_category_form_data = {
         'app_label': 'files',
         'model': 'file',
         'pk': file.pk,
-        'category': getattr(category,'name','0'),
-        'sub_category': getattr(sub_category,'name','0')
+        'category': getattr(category, 'name', '0'),
+        'sub_category': getattr(sub_category, 'name', '0')
     }
 
     if request.method == "POST":
 
         form = form_class(request.POST, request.FILES, instance=file, user=request.user)
-        categoryform = category_form_class(content_type, request.POST, initial= initial_category_form_data, prefix='category')
-        
+        categoryform = category_form_class(content_type, request.POST, initial=initial_category_form_data, prefix='category')
+
         if form.is_valid() and categoryform.is_valid():
             file = form.save(commit=False)
 
             # update all permissions and save the model
             file = update_perms_and_save(request, form, file)
-            
+
             #setup categories
-            category = Category.objects.get_for_object(file,'category')
-            sub_category = Category.objects.get_for_object(file,'sub_category')
-            
+            category = Category.objects.get_for_object(file, 'category')
+            sub_category = Category.objects.get_for_object(file, 'sub_category')
+
             ## update the category of the file
             category_removed = False
             category = categoryform.cleaned_data['category']
-            if category != '0': 
-                Category.objects.update(file ,category,'category')
-            else: # remove
+            if category != '0':
+                Category.objects.update(file, category, 'category')
+            else:  # remove
                 category_removed = True
-                Category.objects.remove(file ,'category')
-                Category.objects.remove(file ,'sub_category')
-            
+                Category.objects.remove(file, 'category')
+                Category.objects.remove(file, 'sub_category')
+
             if not category_removed:
                 # update the sub category of the article
                 sub_category = categoryform.cleaned_data['sub_category']
-                if sub_category != '0': 
-                    Category.objects.update(file, sub_category,'sub_category')
-                else: # remove
-                    Category.objects.remove(file,'sub_category')  
-            
+                if sub_category != '0':
+                    Category.objects.update(file, sub_category, 'sub_category')
+                else:  # remove
+                    Category.objects.remove(file, 'sub_category')
+
             file.save()
 
             return HttpResponseRedirect(reverse('file.search'))
@@ -281,13 +296,12 @@ def edit(request, id, form_class=FileForm, category_form_class=CategoryForm, tem
         form = form_class(instance=file, user=request.user)
         categoryform = category_form_class(content_type, initial=initial_category_form_data, prefix='category')
 
-    return render_to_response(template_name, 
-            {
-                'file': file, 
-                'form':form,
-                'categoryform':categoryform,
-                }, 
-        context_instance=RequestContext(request))
+    return render_to_response(
+        template_name, {
+            'file': file,
+            'form': form,
+            'categoryform': categoryform,
+        }, context_instance=RequestContext(request))
 
 
 @is_enabled('files')
@@ -300,7 +314,7 @@ def bulk_add(request, template_name="files/bulk-add.html"):
         File,
         form=FileForm,
         can_delete=True,
-        fields = (
+        fields=(
             'name',
             'allow_anonymous_view',
             'user_perms',
@@ -343,14 +357,15 @@ def bulk_add(request, template_name="files/bulk-add.html"):
         # Redirect if form_set is edited i.e. not a file select or drag event
         if formset_edit:
             return HttpResponseRedirect(reverse('file.search'))
-        
+
         # Handle json response
         file_qs = File.objects.filter(id__in=file_list)
         file_formset = FileFormSet(queryset=file_qs)
-        html = render_to_response('files/file-formset.html', {
-                   'file_formset': file_formset,
-               }, context_instance=RequestContext(request)).content
-        
+        html = render_to_response(
+            'files/file-formset.html', {
+                'file_formset': file_formset,
+            }, context_instance=RequestContext(request)).content
+
         data = {'form_set': html}
         response = JSONResponse(data, {}, "application/json")
         response['Content-Disposition'] = 'inline; filename=files.json'
@@ -361,8 +376,9 @@ def bulk_add(request, template_name="files/bulk-add.html"):
             'form-INITIAL_FORMS': u'0',
             'form-MAX_NUM_FORMS': u'',
         })
-            
-    return render_to_response(template_name, {
+
+    return render_to_response(
+        template_name, {
             'file_formset': file_formset,
         }, context_instance=RequestContext(request))
 
@@ -371,67 +387,66 @@ def bulk_add(request, template_name="files/bulk-add.html"):
 @login_required
 def add(request, form_class=FileForm, category_form_class=CategoryForm, template_name="files/add.html"):
     # check permission
-    if not has_perm(request.user,'files.add_file'):  
+    if not has_perm(request.user, 'files.add_file'):
         raise Http403
-        
-    content_type = get_object_or_404(ContentType, app_label='files',model='file')
+
+    content_type = get_object_or_404(ContentType, app_label='files', model='file')
 
     if request.method == "POST":
         form = form_class(request.POST, request.FILES, user=request.user)
         categoryform = category_form_class(content_type, request.POST, prefix='category')
         if form.is_valid() and categoryform.is_valid():
             file = form.save(commit=False)
-            
+
             # set up the user information
             file.creator = request.user
             file.creator_username = request.user.username
             file.owner = request.user
             file.owner_username = request.user.username
             file.save()
-            
+
             #setup categories
-            category = Category.objects.get_for_object(file,'category')
-            sub_category = Category.objects.get_for_object(file,'sub_category')
-            
+            category = Category.objects.get_for_object(file, 'category')
+            sub_category = Category.objects.get_for_object(file, 'sub_category')
+
             ## update the category of the file
             category_removed = False
             category = categoryform.cleaned_data['category']
-            if category != '0': 
-                Category.objects.update(file ,category,'category')
-            else: # remove
+            if category != '0':
+                Category.objects.update(file, category, 'category')
+            else:  # remove
                 category_removed = True
-                Category.objects.remove(file ,'category')
-                Category.objects.remove(file ,'sub_category')
-            
+                Category.objects.remove(file, 'category')
+                Category.objects.remove(file, 'sub_category')
+
             if not category_removed:
                 # update the sub category of the article
                 sub_category = categoryform.cleaned_data['sub_category']
-                if sub_category != '0': 
-                    Category.objects.update(file, sub_category,'sub_category')
-                else: # remove
-                    Category.objects.remove(file,'sub_category')  
-            
+                if sub_category != '0':
+                    Category.objects.update(file, sub_category, 'sub_category')
+                else:  # remove
+                    Category.objects.remove(file, 'sub_category')
+
             #Save relationships
             file.save()
 
             # assign creator permissions
-            ObjectPermission.objects.assign(file.creator, file) 
-            
+            ObjectPermission.objects.assign(file.creator, file)
+
             return HttpResponseRedirect(reverse('file.search'))
     else:
         initial_category_form_data = {
             'app_label': 'files',
             'model': 'file',
-            'pk': 0, #not used for this view but is required for the form
+            'pk': 0,  # not used for this view but is required for the form
         }
         form = form_class(user=request.user)
         categoryform = category_form_class(content_type, initial=initial_category_form_data, prefix='category')
-    return render_to_response(template_name, 
-            {
-                'form':form,
-                'categoryform':categoryform,
-            }, 
-        context_instance=RequestContext(request))
+    return render_to_response(
+        template_name, {
+            'form': form,
+            'categoryform': categoryform,
+        }, context_instance=RequestContext(request))
 
 
 @is_enabled('files')
@@ -451,8 +466,10 @@ def delete(request, id, template_name="files/delete.html"):
         else:
             return HttpResponseRedirect(reverse('file.search'))
 
-    return render_to_response(template_name, {'file': file},
-        context_instance=RequestContext(request))
+    return render_to_response(
+        template_name, {
+            'file': file
+        }, context_instance=RequestContext(request))
 
 
 @login_required
@@ -463,17 +480,17 @@ def tinymce(request, template_name="files/templates/tinymce.html"):
     Examples of "this": Articles, Pages, Releases module
     """
     from django.contrib.contenttypes.models import ContentType
-    params = {'app_label': 0, 'model': 0, 'instance_id':0}
-    files = File.objects.none() # EmptyQuerySet
-    #all_files = File.objects.filter(creator=request.user)
+    params = {'app_label': 0, 'model': 0, 'instance_id': 0}
+    files = File.objects.none()  # EmptyQuerySet
     all_files = None
+
     # if all required parameters are in the GET.keys() list
-    if not set(params.keys()) - set(request.GET.keys()):        
+    if not set(params.keys()) - set(request.GET.keys()):
 
         for item in params:
             params[item] = request.GET[item]
 
-        try: # get content type
+        try:  # get content type
             contenttype = ContentType.objects.get(app_label=params['app_label'], model=params['model'])
 
             instance_id = params['instance_id']
@@ -481,20 +498,23 @@ def tinymce(request, template_name="files/templates/tinymce.html"):
                 instance_id = 0
 
             files = File.objects.filter(
-                content_type=contenttype, 
-                object_id=instance_id)
+                content_type=contenttype,
+                object_id=instance_id
+            )
 
             for media_file in files:
                 file, ext = os.path.splitext(media_file.file.url)
                 media_file.file.url_thumbnail = '%s_thumbnail%s' % (file, ext)
                 media_file.file.url_medium = '%s_medium%s' % (file, ext)
                 media_file.file.url_large = '%s_large%s' % (file, ext)
-        except ContentType.DoesNotExist: raise Http404
+        except ContentType.DoesNotExist:
+            raise Http404
 
-    return render_to_response(template_name, {
-        "media": files,
-        "all_media": all_files, 
-        'csrf_token':csrf_get_token(request),
+    return render_to_response(
+        template_name, {
+            "media": files,
+            "all_media": all_files,
+            'csrf_token': csrf_get_token(request),
         }, context_instance=RequestContext(request))
 
 
@@ -537,9 +557,9 @@ def swfupload(request):
             print e
 
         d = {
-            "id" : file.id,
-            "name" : file.name,
-            "url" : file.file.url,
+            "id": file.id,
+            "name": file.name,
+            "url": file.file.url,
         }
 
         return HttpResponse(json.dumps([d]), mimetype="text/plain")
@@ -548,8 +568,10 @@ def swfupload(request):
 @login_required
 def tinymce_upload_template(request, id, template_name="files/templates/tinymce_upload.html"):
     file = get_object_or_404(File, pk=id)
-    return render_to_response(template_name, {'file': file}, 
-        context_instance=RequestContext(request))
+    return render_to_response(
+        template_name, {
+            'file': file
+        }, context_instance=RequestContext(request))
 
 
 @is_enabled('files')
@@ -561,7 +583,6 @@ def report_most_viewed(request, form_class=MostViewedForm, template_name="files/
     """
     from django.db.models import Count
     from datetime import date
-    from datetime import timedelta
     from dateutil.relativedelta import relativedelta
 
     start_dt = date.today() + relativedelta(months=-2)
@@ -594,23 +615,25 @@ def report_most_viewed(request, form_class=MostViewedForm, template_name="files/
 
     EventLog.objects.log()
 
-    return render_to_response(template_name, {
-        'form': form,
-        'event_logs': event_logs
+    return render_to_response(
+        template_name, {
+            'form': form,
+            'event_logs': event_logs
         }, context_instance=RequestContext(request))
 
+
 def display_less(request, path):
     """
     Display the .less files
     """
     content = ''
     if path:
-        full_path = '%s/%s.less' % (settings.S3_SITE_ROOT_URL, 
-                                    path)
+        full_path = '%s/%s.less' % (settings.S3_SITE_ROOT_URL, path)
         url_obj = urllib2.urlopen(full_path)
         content = url_obj.read()
     return HttpResponse(content, mimetype="text/css")
 
+
 def redirect_to_s3(request, path, file_type='themes'):
     """
     Redirect to S3
@@ -626,7 +649,7 @@ def redirect_to_s3(request, path, file_type='themes'):
                 if os.path.splitext(full_path)[1] == '.css':
                     content_type = 'text/css'
                 else:
-                    content_type = mimetypes.guess_type(full_path)[0] 
+                    content_type = mimetypes.guess_type(full_path)[0]
                 return HttpResponse(content, mimetype=content_type)
         else:
             url = '%s/%s' % (settings.THEMES_DIR, path)
@@ -636,6 +659,6 @@ def redirect_to_s3(request, path, file_type='themes'):
 
 class JSONResponse(HttpResponse):
     """JSON response class."""
-    def __init__(self,obj='',json_opts={},mimetype="application/json",*args,**kwargs):
-        content = simplejson.dumps(obj,**json_opts)
-        super(JSONResponse,self).__init__(content,mimetype,*args,**kwargs)
+    def __init__(self, obj='', json_opts={}, mimetype="application/json", *args, **kwargs):
+        content = simplejson.dumps(obj, **json_opts)
+        super(JSONResponse, self).__init__(content, mimetype, *args, **kwargs)
